@@ -1184,11 +1184,18 @@ class DebuggerUI(FrameVarInfoKeeper):
         self.screen = ThreadsafeScreen()
 
         if curses:
-            curses.setupterm()
-            color_support = curses.tigetnum('colors')
+            try:
+                curses.setupterm()
+            except:
+                # Something went wrong--oh well. Nobody will die if their
+                # 256 color support breaks. Just carry on without it.
+                # https://github.com/inducer/pudb/issues/78
+                pass
+            else:
+                color_support = curses.tigetnum('colors')
 
-            if color_support == 256:
-                self.screen.set_terminal_properties(256)
+                if color_support == 256:
+                    self.screen.set_terminal_properties(256)
 
         self.setup_palette(self.screen)
 
@@ -1401,7 +1408,7 @@ class DebuggerUI(FrameVarInfoKeeper):
                 self.message("Package 'pygments' not found. "
                         "Syntax highlighting disabled.")
 
-        WELCOME_LEVEL = "e013"
+        WELCOME_LEVEL = "e014"
         if CONFIG["seen_welcome"] < WELCOME_LEVEL:
             CONFIG["seen_welcome"] = WELCOME_LEVEL
             from pudb import VERSION
@@ -1418,10 +1425,14 @@ class DebuggerUI(FrameVarInfoKeeper):
                     "(invoked by hitting '?' after this message) should get you "
                     "on your way.\n"
 
+                    "\nChanges in version 2013.3.4:\n\n"
+                    "- Don't die if curses doesn't like what stdin/out are\n"
+                    "  connected to.\n"
+
                     "\nChanges in version 2013.3.3:\n\n"
                     "- As soon as pudb is loaded, you can break to the debugger by\n"
-                    "  evaluating the expression 'pu.db', where 'pu' is a new 'builtin'\n"
-                    "  that pudb has rudely shoved into the interpreter.\n"
+                    "  evaluating the expression 'pu.db', where 'pu' is a new \n"
+                    "  'builtin' that pudb has rudely shoved into the interpreter.\n"
 
                     "\nChanges in version 2013.3.2:\n\n"
                     "- Don't attempt to do signal handling if a signal handler\n"
